@@ -7,13 +7,15 @@ class SynchronizeRemoteNginxLogsWithLocalRepository:
     @staticmethod
     def process(source_server: Server, destination_server: Server) -> None:
         try:
-            sysrsync.run(
-                source=source_server.source_path,
-                source_ssh=source_server.host,
-                destination=destination_server.source_path,
-                destination_ssh=destination_server.host,
-                options=["-a"],
-            )
+            for files in source_server.include_files:
+                sysrsync.run(
+                    source=f"{source_server.source_path}{files}",
+                    source_ssh=source_server.host,
+                    destination=destination_server.source_path,
+                    destination_ssh=destination_server.host,
+                    sync_source_contents=False,
+                    options=["-a"],
+                )
         except Exception as error:
             raise FilesSynchronizationError(
                 f"Files synchronization failed with source: {source_server.host}:{source_server.source_path} "
